@@ -1008,25 +1008,6 @@ glade_inspector_cell_function (GtkTreeViewColumn *tree_column,
 	}
 }
 
-static gboolean
-glade_inspector_search_func (GtkTreeModel *model,
-			     gint column,
-			     const gchar *key,
-			     GtkTreeIter *iter,
-			     gpointer search_data)
-{
-	GladeWidget *widget;
-
-	gtk_tree_model_get (model, iter, WIDGET_COLUMN, &widget, -1);
-	
-	if (!widget)
-		return TRUE;
-	
-	g_return_val_if_fail (widget->name != NULL, TRUE);
-	
-	return ! g_str_has_prefix (widget->name, key);
-}
-
 static void
 add_columns (GtkTreeView *view)
 {
@@ -1062,12 +1043,7 @@ add_columns (GtkTreeView *view)
 						 GINT_TO_POINTER (CELL_MISC), NULL);
 	
 	gtk_tree_view_append_column (view, column);	
-	
-	/* Set search column */
-	gtk_tree_view_set_search_equal_func (view, glade_inspector_search_func, NULL, NULL);
-	gtk_tree_view_set_enable_search (view, TRUE);
-	gtk_tree_view_set_search_column (view, WIDGET_COLUMN);
-	
+		
 	gtk_tree_view_set_headers_visible (view, FALSE);
 }
 
